.. _api_reference:

*************
API Reference
*************

.. module:: lollipop

Data
====

.. autodata:: lollipop.types.MISSING

Types
=====

.. automodule:: lollipop.types
    :members:
    :exclude-members: MISSING

Validators
==========

.. automodule:: lollipop.validators
    :members:

Errors
======

.. automodule:: lollipop.errors
    :members:

Type registry
=============

.. automodule:: lollipop.type_registry
    :members:
